@@ -104,9 +104,8 @@ class NetcatsTool(Tool):
                 state = 'filtered'
             else:
                 state = 'FIXME-' + errmsg.replace(' ', '-')
-                self.stderr = True
-        except gevent.GreenletExit:
-            state = 'filtered'
+        #except gevent.GreenletExit:
+        #    state = 'filtered'
 
         done = False
         stdin = self._stdin_pipe[0]
@@ -192,7 +191,7 @@ class NetcatsTool(Tool):
     def __timeout__(self):
         if hasattr(self, '_addr'):
             host, port = self._addr
-            return '{0} {1} filtered\n'.format(host, port)
+            return 'timeout {0} {1}\n'.format(host, port)
         return None
 
     def feed_stdin(self, data):
