@@ -11,7 +11,6 @@ import socket
 
 import gevent
 
-from xnet.debug import pdb
 from xnet.tools import Tool
 
 
@@ -28,7 +27,7 @@ class ResolvTool(Tool):
     ]
 
     def __parse__(self, line, iterator):
-        item = line.strip()
+        self._item = item = line.strip()
         result = {}
         if self.options.reverse:
             result['ip'] = item
@@ -49,9 +48,24 @@ class ResolvTool(Tool):
             ip = socket.gethostbyname(host)
             result['ip'] = ip
         except socket.error, e:
-            pdb.set_trace()
-        except gevent.GreenletExit:
-            result['state'] = 'timeout'
+            #
+            # errno numbers differ between platforms,
+            # but tests for 'closed' and 'filtered'
+            # below should work universally.
+            #
+            errmsg = e.strerror.lower()
+            if 'connection refused' in errmsg:
+                errmsg = 'closed'
+            elif 'timed out' in errmsg:
+                errmsg = 'filtered'
+            else:
+                errmsg = errmsg.replace(' ', '-').replace(',', '-')
+            errmsg = '{0} {1}'.format(host, errmsg)
+            self.set_error(errmsg) 
+            self.stderr = True
+            return None
+        #except gevent.GreenletExit:
+        #    result['state'] = 'timeout'
         finally:
             pass
         return result
@@ -64,9 +78,24 @@ class ResolvTool(Tool):
             result['host'] = addrlist[0]
             result['hostlist'] = addrlist
         except socket.error, e:
-            pdb.set_trace()
-        except gevent.GreenletExit:
-            result['state'] = 'timeout'
+            #
+            # errno numbers differ between platforms,
+            # but tests for 'closed' and 'filtered'
+            # below should work universally.
+            #
+            errmsg = e.strerror.lower()
+            if 'connection refused' in errmsg:
+                errmsg = 'closed'
+            elif 'timed out' in errmsg:
+                errmsg = 'filtered'
+            else:
+                errmsg = errmsg.replace(' ', '-').replace(',', '-')
+            errmsg = '{0} {1}'.format(ip, errmsg)
+            self.set_error(errmsg) 
+            self.stderr = True
+            return None
+        #except gevent.GreenletExit:
+        #    result['state'] = 'timeout'
         finally:
             pass
         return result
@@ -78,6 +107,9 @@ class ResolvTool(Tool):
         )
         return output
 
+    def __timeout__(self):
+        output = 'timeout {0}'.format(self._item)
+
 
 def main():
     import xnet.tools
