@@ -150,5 +150,6 @@ def main():
 
 
 if __name__ == "__main__":
-    doctest.testmod()
-    unittest.main()
+    main()
+    #doctest.testmod()
+    #unittest.main()
